@@ -13,20 +13,25 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #include <config.h>
 #include <cassert>
 #include <pan/general/debug.h>
-#include <pan/general/foreach.h>
+#include <pan/general/macros.h>
 #include <pan/data/data.h>
+#include <gmime/gmime.h>
+
+//#include <glib/gprintf.h>
+#include <glib.h>
+
 #include "article-filter.h"
 
 using namespace pan;
 
-const StringView&
+const StringView
 ArticleFilter :: get_header (const Article& a, const Quark& header_name) const
 {
   static const StringView empty;
@@ -37,7 +42,7 @@ ArticleFilter :: get_header (const Article& a, const Quark& header_name) const
   if (header_name == message_ID) return a.message_id.to_view ();
 
   std::cerr << LINE_ID << ' ' << PACKAGE_STRING << " is misparsing \"" << header_name << "\".\n"
-            << "Please file a bug report to http://bugzilla.gnome.org/enter_bug.cgi?product=Pan\n";
+            << "Please file a bug report to https://gitlab.gnome.org/GNOME/pan/issues\n";
   return empty;
 }
 
@@ -48,16 +53,19 @@ ArticleFilter :: test_article (const Data        & data,
                                const Quark       & group,
                                const Article     & article) const
 {
+  const ArticleCache & cache(data.get_cache());
   bool pass (false);
   switch (criteria._type)
   {
     case FilterInfo::AGGREGATE_AND:
       pass = true;
-      foreach_const (FilterInfo::aggregates_t, criteria._aggregates, it) {
-        if (!test_article (data, *it, group, article)) {
-          pass = false;
-          break;
-        }
+      foreach_const (FilterInfo::aggregatesp_t, criteria._aggregates, it) {
+        // assume test passes if test needs body but article not cached
+        if (!(*it)->_needs_body || cache.contains(article.message_id) )
+          if (!test_article (data, **it, group, article)) {
+            pass = false;
+            break;
+          }
       }
       break;
 
@@ -66,11 +74,13 @@ ArticleFilter :: test_article (const Data        & data,
         pass = true;
       else {
         pass = false;
-        foreach_const (FilterInfo::aggregates_t, criteria._aggregates, it) {
-          if (test_article (data, *it, group, article)) {
-            pass = true;
-            break;
-          }
+        foreach_const (FilterInfo::aggregatesp_t, criteria._aggregates, it) {
+          // assume test fails if test needs body but article not cached
+          if (!(*it)->_needs_body || cache.contains(article.message_id) )
+            if (test_article (data, **it, group, article)) {
+              pass = true;
+              break;
+            }
         }
       }
       break;
@@ -83,6 +93,10 @@ ArticleFilter :: test_article (const Data        & data,
       pass = data.has_from_header (article.author.to_view());
       break;
 
+    case FilterInfo::IS_READ:
+      pass = data.is_read (&article);
+      break;
+
     case FilterInfo::IS_UNREAD:
       pass = !data.is_read (&article);
       break;
@@ -118,7 +132,7 @@ ArticleFilter :: test_article (const Data        & data,
         }
         else if (criteria._text._impl_text.find("(.*:){") != std::string::npos) // user is filtering by # of crossposts
         {
-          const char * search = "(.*:){";
+          const char * search = "(.*:){";//}
           std::string::size_type pos = criteria._text._impl_text.find (search) + strlen(search);
           const int ge = atoi (criteria._text._impl_text.c_str() + pos);
           FilterInfo tmp;
@@ -145,7 +159,7 @@ ArticleFilter :: test_article (const Data        & data,
             s += xit->group;
             s += ':';
             char buf[32];
-            snprintf (buf, sizeof(buf), "%lu", xit->number);
+            g_snprintf (buf, sizeof(buf), "%" G_GUINT64_FORMAT, static_cast<uint64_t>(xit->number));
             s += buf;
             s += ' ';
           }
@@ -176,7 +190,24 @@ ArticleFilter :: test_article (const Data        & data,
         pass = criteria._text.test (s);
       }
       else
-        pass = criteria._text.test (get_header(article, criteria._header));
+        if (!criteria._needs_body)
+          pass = criteria._text.test (get_header(article, criteria._header));
+        else
+        {
+          if (cache.contains(article.message_id)) {
+            ArticleCache::mid_sequence_t mid(1, article.message_id);
+#ifdef HAVE_GMIME_CRYPTO
+            GPGDecErr err;
+            GMimeMessage *msg = cache.get_message(mid,err);
+#else
+            GMimeMessage *msg = cache.get_message(mid);
+#endif
+            const char *hdr = g_mime_object_get_header(GMIME_OBJECT(msg), criteria._header);
+            pass = criteria._text.test (hdr);
+            g_object_unref(msg);
+          }
+          else pass = false;
+        }
       break;
 
     case FilterInfo::SCORE_GE:
