@@ -58,7 +58,7 @@ DataImpl :: GroupHeaders :: ~GroupHeaders ()
 DataImpl :: ArticleNode*
 DataImpl :: GroupHeaders :: find_node (const Quark& mid)
 {
-  ArticleNode * node (0);
+  ArticleNode * node (nullptr);
   nodes_t::iterator it (_nodes.find (mid));
   if (it != _nodes.end())
     node = it->second;
@@ -68,7 +68,7 @@ DataImpl :: GroupHeaders :: find_node (const Quark& mid)
 const DataImpl :: ArticleNode*
 DataImpl :: GroupHeaders :: find_node (const Quark& mid) const
 {
-  const ArticleNode * node (0);
+  const ArticleNode * node (nullptr);
   nodes_t::const_iterator it (_nodes.find (mid));
   if (it != _nodes.end())
     node = it->second;
@@ -89,7 +89,7 @@ DataImpl :: GroupHeaders :: find_parent_message_id (const Quark& mid) const
 const Article*
 DataImpl :: GroupHeaders :: find_article (const Quark& message_id) const
 {
-  Article *a (0);
+  Article *a (nullptr);
 
   const ArticleNode * node (find_node (message_id));
   if (node)
@@ -101,7 +101,7 @@ DataImpl :: GroupHeaders :: find_article (const Quark& message_id) const
 Article*
 DataImpl :: GroupHeaders :: find_article (const Quark& message_id)
 {
-  Article *a(0);
+  Article *a(nullptr);
 
   const ArticleNode * node (find_node (message_id));
   if (node)
@@ -116,7 +116,7 @@ DataImpl :: GroupHeaders :: remove_articles (const quarks_t& mids)
   nodes_v nodes;
   find_nodes (mids, _nodes, nodes);
   foreach (nodes_v, nodes, it)
-    (*it)->_article = 0;
+    (*it)->_article = nullptr;
   _dirty = true;
 }
 
@@ -124,14 +124,14 @@ const DataImpl :: GroupHeaders*
 DataImpl :: get_group_headers (const Quark& group) const
 {
    group_to_headers_t::const_iterator it (_group_to_headers.find(group));
-   return it==_group_to_headers.end() ? 0 : it->second;
+   return it==_group_to_headers.end() ? nullptr : it->second;
 }
 
 DataImpl :: GroupHeaders*
 DataImpl :: get_group_headers (const Quark& group)
 {
    group_to_headers_t::iterator it (_group_to_headers.find(group));
-   return it==_group_to_headers.end() ? 0 : it->second;
+   return it==_group_to_headers.end() ? nullptr : it->second;
 }
 
 void
@@ -149,6 +149,15 @@ DataImpl :: GroupHeaders :: build_references_header (const Article* article, std
   }
 }
 
+void DataImpl::GroupHeaders::reserve(Article_Count articles)
+{
+  _art_chunk.reserve(static_cast<Article_Count::type>(articles));
+  //A note - the number of nodes is very rarely the same as the number of
+  //articles, but it is generally not far out, so at worse you'll end up with
+  //two allocations
+  _node_chunk.reserve(static_cast<Article_Count::type>(articles));
+}
+
 void
 DataImpl :: get_article_references (const Quark& group, const Article* article, std::string& setme) const
 {
@@ -186,7 +195,7 @@ void
 DataImpl :: unref_group   (const Quark& group)
 {
   GroupHeaders * h (get_group_headers (group));
-  pan_return_if_fail (h != 0);
+  pan_return_if_fail (h != nullptr);
 
   --h->_ref;
 //  std::cerr << LINE_ID << " group " << group << " refcount down to " << h->_ref << std::endl;
@@ -260,7 +269,7 @@ DataImpl :: load_article (const Quark       & group,
 #endif
 
   GroupHeaders * h (get_group_headers (group));
-  pan_return_if_fail (h!=0);
+  pan_return_if_fail (h!=nullptr);
 
   // populate the current node
   const Quark& mid (article->message_id);
@@ -301,7 +310,7 @@ DataImpl :: load_article (const Quark       & group,
     {
       //std::cerr << LINE_ID << " haven't mapped " << new_parent_mid << " before..." << std::endl;
       ArticleNode * new_parent_node (h->_nodes[new_parent_mid]);
-      const bool found (new_parent_node != 0);
+      const bool found (new_parent_node != nullptr);
       if (!found) {
         //std::cerr << LINE_ID << " didn't find it; adding new node for " << new_parent_mid << std::endl;
         static const ArticleNode blank_node;
@@ -311,7 +320,7 @@ DataImpl :: load_article (const Quark       & group,
       }
       node->_parent = new_parent_node;
       if (find_ancestor (new_parent_node, new_parent_mid)) {
-        node->_parent = 0;
+        node->_parent = nullptr;
         //std::cerr << LINE_ID << " someone's been munging References headers to cause trouble!" << std::endl;
         break;
       }
@@ -335,11 +344,11 @@ DataImpl :: load_article (const Quark       & group,
 
       // unlink from old parent
       old_parent_node->_children.remove (node);
-      node->_parent = 0;
+      node->_parent = nullptr;
 
       // link to new parent
       ArticleNode * new_parent_node (h->_nodes[new_parent_mid]);
-      const bool found (new_parent_node != 0);
+      const bool found (new_parent_node != nullptr);
       if (!found) {
         //std::cerr << LINE_ID << " didn't find it; adding new node for " << new_parent_mid << std::endl;
         static const ArticleNode blank_node;
@@ -348,8 +357,8 @@ DataImpl :: load_article (const Quark       & group,
         new_parent_node->_mid = new_parent_mid;
       }
       node->_parent = new_parent_node;
-      if (find_ancestor (new_parent_node, new_parent_mid) != 0) {
-        node->_parent = 0;
+      if (find_ancestor (new_parent_node, new_parent_mid) != nullptr) {
+        node->_parent = nullptr;
         //std::cerr << LINE_ID << " someone's been munging References headers to cause trouble!" << std::endl;
         break;
       }
@@ -360,7 +369,7 @@ DataImpl :: load_article (const Quark       & group,
   }
 
   // recursion?
-  assert (find_ancestor(article_node, article->message_id) == 0);
+  assert (find_ancestor(article_node, article->message_id) == nullptr);
 }
 
 #if 0
@@ -397,7 +406,7 @@ DataImpl :: load_part (const Quark          & group,
 {
    GroupHeaders * h = get_group_headers (group);
    Article * a (h->find_article (mid));
-   pan_return_if_fail (a != 0);
+   pan_return_if_fail (a != nullptr);
 
    if (a->add_part (number, part_mid, bytes))
      a->lines += lines;
@@ -405,13 +414,13 @@ DataImpl :: load_part (const Quark          & group,
 
 namespace
 {
-  unsigned long view_to_ul (const StringView& view)
+  unsigned long long view_to_ull (const StringView& view)
   {
-    unsigned long val (0);
+    unsigned long long val (0ull);
     if (!view.empty()) {
       errno = 0;
-      val = strtoul (view.str, 0, 10);
-      if (errno) val = 0ul;
+      val = strtoull (view.str, nullptr, 10);
+      if (errno) val = 0ull;
     }
     return val;
   }
@@ -424,10 +433,10 @@ DataImpl :: load_headers (const DataIO   & data_io,
   TimeElapsed timer;
 
   GroupHeaders * h (get_group_headers (group));
-  assert (h != 0);
+  assert (h != nullptr);
 
-  unsigned long article_count (0);
-  unsigned long unread_count (0);
+  Article_Count article_count (0);
+  Article_Count unread_count (0);
   StringView line;
   bool success (false);
   quarks_t servers;
@@ -478,8 +487,10 @@ DataImpl :: load_headers (const DataIO   & data_io,
       // each article in this group...
       unsigned int expire_count (0);
       in->getline (line);
-      //const unsigned long article_qty = view_to_ul (line); /* unused */
-      const time_t now (time (0));
+      Article_Count const article_qty{line};
+      h->reserve(article_qty);
+
+      const time_t now (time (nullptr));
       PartBatch part_batch;
       for (;;)
       {
@@ -522,7 +533,7 @@ DataImpl :: load_headers (const DataIO   & data_io,
         }
 
         // date-posted line
-        a.time_posted = view_to_ul (s);
+        a.time_posted = view_to_ull (s);
         const int days_old ((now - a.time_posted) / (24*60*60));
 
         // xref line
@@ -535,7 +546,7 @@ DataImpl :: load_headers (const DataIO   & data_io,
           if (tok.pop_token(server_tok,':') && tok.pop_token(group_tok,':')) {
             target_it->server = server_tok;
             target_it->group = group_tok.len==1 ? xref_lookup[(int)*group_tok.str] : Quark(group_tok);
-            target_it->number = g_ascii_strtoull (tok.str, NULL, 10);
+            target_it->number = Article_Number(tok);
             const Server * server (find_server (target_it->server));
             if (server && ((!server->article_expiration_age) || (days_old <= server->article_expiration_age)))
               ++target_it;
@@ -559,7 +570,7 @@ DataImpl :: load_headers (const DataIO   & data_io,
         s.ltrim(); if (s.pop_token (tok)) a.lines = atoi (tok.str); // this field was added in 0.115
 
         // found parts...
-        part_batch.init (a.message_id, total_part_count, found_part_count);
+        part_batch.init (a.message_id, total_part_count);
 //        std::cerr<<"article "<<a.message_id<<" "<<total_part_count<<" "<<found_part_count<<std::endl;
         for (int i(0), count(found_part_count); i<count; ++i)
         {
@@ -581,7 +592,7 @@ DataImpl :: load_headers (const DataIO   & data_io,
             s.pop_token (part_mid);
             if (part_mid.len==1 && *part_mid.str=='"')
               part_mid = a.message_id.to_view ();
-            s.pop_token(tok); part_bytes = view_to_ul (tok);
+            s.pop_token(tok); part_bytes = view_to_ull (tok);
             part_batch.add_part (number, part_mid, part_bytes);
 
             if (s.pop_token(tok)) a.lines += atoi (tok.str); // this field was removed in 0.115
@@ -625,9 +636,9 @@ DataImpl :: load_headers (const DataIO   & data_io,
   if (success) {
     const double seconds = timer.get_seconds_elapsed ();
     Log::add_info_va (
-      _("Loaded %lu articles for \"%s\" in %.1f seconds (%.0f per second)"),
-      article_count, group.c_str(), seconds,
-      article_count/(fabs(seconds)<0.001?0.001:seconds));
+      _("Loaded %llu articles for \"%s\" in %.1f seconds (%.0f per second)"),
+      static_cast<uint64_t>(article_count), group.c_str(), seconds,
+      static_cast<uint64_t>(article_count)/(fabs(seconds)<0.001?0.001:seconds));
   }
 }
 
@@ -700,7 +711,7 @@ DataImpl :: save_headers (DataIO                       & data_io,
 {
   const char endl ('\n');
   const GroupHeaders * h (get_group_headers (group));
-  assert (h != 0);
+  assert (h != nullptr);
 
   part_count = 0;
   article_count = 0;
@@ -908,7 +919,7 @@ DataImpl :: mark_read (const Article  ** articles,
   foreach_const (group_to_changed_mids_t, group_to_changed_mids, it) {
     const Quark& group (it->first);
     ReadGroup& g (_read_groups[group]);
-    const size_t n (it->second.size());
+    const Article_Count n{it->second.size()};
     if (read)
       g.decrement_unread (n);
     else
@@ -926,7 +937,7 @@ bool
 DataImpl :: is_read (const Article* a) const
 {
   // if it's read on any server, the whole thing is read.
-  if (a != 0)  {
+  if (a != nullptr)  {
     foreach_const (Xref, a->xref, xit) {
       const ReadGroup::Server * rgs (find_read_group_server (xit->group, xit->server));
       if (rgs && rgs->_read.is_marked (xit->number))
@@ -1085,8 +1096,8 @@ namespace
   /** used by delete_articles */
   struct PerGroup {
     quarks_t mids;
-    int unread;
-    int count;
+    Article_Count unread;
+    Article_Count count;
     PerGroup(): unread(0), count(0) {}
   };
 }
@@ -1114,8 +1125,8 @@ DataImpl :: group_clear_articles (const Quark& group)
 
   // fire a 'count changed' event.
   ReadGroup& g (_read_groups[group]);
-  g._article_count = 0;
-  g._unread_count = 0;
+  g._article_count = static_cast<Article_Count>(0);
+  g._unread_count = static_cast<Article_Count>(0);
   fire_group_counts (group, g._unread_count, g._article_count);
 }
 
