@@ -78,7 +78,7 @@ DataImpl :: add_new_server ()
 Data :: Server*
 DataImpl :: find_server (const Quark& server)
 {
-  Server * retval (0);
+  Server * retval (nullptr);
 
   servers_t::iterator it (_servers.find (server));
   if (it != _servers.end())
@@ -89,7 +89,7 @@ DataImpl :: find_server (const Quark& server)
 const Data :: Server*
 DataImpl :: find_server (const Quark& server) const
 {
-  const Server * retval (0);
+  const Server * retval (nullptr);
 
   servers_t::const_iterator it (_servers.find (server));
   if (it != _servers.end())
@@ -240,7 +240,6 @@ DataImpl :: get_server_auth (const Quark   & server,
 #ifndef HAVE_GKR
     setme_password = g_strdup(s->password.c_str());
 #else
-#if GTK_CHECK_VERSION(3,0,0)
     if (!use_gkr)
     {
       setme_password = g_strdup(s->password.c_str());
@@ -265,41 +264,6 @@ DataImpl :: get_server_auth (const Quark   & server,
           s->gkr_pw = pw.pw;
       }
     }
-#else
-    if (!use_gkr)
-    {
-      setme_password = g_strdup(s->password.c_str());
-    }
-    else if (s->gkr_pw)
-    {
-      setme_password = s->gkr_pw;
-    }
-    else
-    {
-      PasswordData pw;
-      pw.server = s->host;
-      pw.user = s->username;
-      switch (password_decrypt(pw))
-      {
-        case GNOME_KEYRING_RESULT_NO_MATCH:
-          Log::add_info_va(_("There seems to be no password set for server %s."), s->host.c_str());
-          break;
-
-        case GNOME_KEYRING_RESULT_NO_KEYRING_DAEMON:
-          Log::add_urgent_va (_("GNOME Keyring denied access to the passwords."), s->host.c_str());
-          break;
-
-        case GNOME_KEYRING_RESULT_OK:
-//          setme_password.assign(pw.pw.str, pw.pw.len);
-          setme_password = pw.pw;
-          s->gkr_pw = pw.pw;
-          break;
-
-        default:
-          break;
-      }
-    }
-#endif /* GTK_CHECK_VERSION(3,0,0) */
 #endif
   }
 
@@ -515,10 +479,10 @@ DataImpl :: load_server_properties (const DataIO& source)
   p.start_element = start_element;
   p.end_element = end_element;
   p.text = text;
-  p.passthrough = 0;
-  p.error = 0;
-  GMarkupParseContext* c = g_markup_parse_context_new (&p, (GMarkupParseFlags)0, &spc, 0);
-  GError * gerr (0);
+  p.passthrough = nullptr;
+  p.error = nullptr;
+  GMarkupParseContext* c = g_markup_parse_context_new (&p, (GMarkupParseFlags)0, &spc, nullptr);
+  GError * gerr (nullptr);
   if (!txt.empty())
     g_markup_parse_context_parse (c, txt.c_str(), txt.size(), &gerr);
   if (gerr) {
