@@ -28,7 +28,7 @@
 namespace pan
 {
    /**
-    * A shallow copy a C string, plus utilities to let us 
+    * A shallow copy a C string, plus utilities to let us
     * substring, tokenize, walk, search, or otherwise
     * manipulate it without having to modify the original or
     * allocate new strings.
@@ -43,12 +43,12 @@ namespace pan
                             size_t       str_a_len,
                             const char * str_b,
                             size_t       str_b_len);
-                                                                                                                        
+
          static char* strchr (const char * haystack,
                               size_t       haystack_len,
                               char         needle)
            { return (char*) memchr (haystack, needle, haystack_len); }
-                                                                                                                        
+
          static char* strrchr (const char * haystack,
                                size_t       haystack_len,
                                char         needle);
@@ -80,12 +80,13 @@ namespace pan
 
       public:
 
-         StringView (): str(0), len(0) {}
+         StringView (): str(nullptr), len(0) {}
          StringView (const std::string& s) { assign(s); }
          StringView (const char * s) { assign(s); }
          StringView (const char * s, size_t l) { assign(s,l); }
          StringView (const char * s, const char * e) { assign(s,e-s); }
          StringView (const StringView& p): str(p.str), len(p.len) {}
+         StringView& operator=(StringView const &) = default;
          ~StringView () { str = (char*)0xDEADBEEF; len = (size_t)~0; }
 
       public:
@@ -128,7 +129,7 @@ namespace pan
             return strcmp (str, len, s, l); }
 
          char* strchr (char needle, size_t p=0) const {
-            return p<len ? strchr (str+p, len-p, needle) : 0; }
+            return p<len ? strchr (str+p, len-p, needle) : nullptr; }
 
          char* strrchr (char needle) const {
             return strrchr (str, len, needle); }
@@ -151,7 +152,7 @@ namespace pan
          StringView& operator= (const char * s) { str=s; len=s?strlen(s):0; return *this; }
          void assign (const char * s, size_t l) { str=s; len=l; }
 
-         void clear () { str=0; len=0; }
+         void clear () { str=nullptr; len=0; }
 
          void trim ();
          void ltrim ();
