@@ -17,6 +17,8 @@
  *
  */
 
+#include "body-pane.h"
+
 #include <config.h>
 #include <cctype>
 #include <cmath>
@@ -35,7 +37,6 @@
 #include <pan/usenet-utils/mime-utils.h>
 #include <pan/usenet-utils/url-find.h>
 #include <pan/icons/pan-pixbufs.h>
-#include "body-pane.h"
 #include "pad.h"
 #include "tango-colors.h"
 #include "xface.h"
@@ -47,11 +48,13 @@
   #include <webkit/webkit.h>
 #endif
 
+#include <pan/general/null.h>
+
 #define FIRST_PICTURE "first-picture"
 
 #define FACE_SIZE 48
 
-using namespace pan;
+namespace pan {
 
 /***
 ****
@@ -76,8 +79,8 @@ namespace
   const guint8 * pixbuf_txt;
   GdkPixbuf * pixbuf;
   } icons[NUM_ICONS] = {
-    { icon_sig_ok,          0 },
-    { icon_sig_fail,        0 }
+    { icon_sig_ok,          nullptr },
+    { icon_sig_fail,        nullptr }
   };
 }
 
@@ -170,7 +173,7 @@ namespace
     g_object_set_data (G_OBJECT(o), FULLSIZE, GINT_TO_POINTER(b));
   }
   bool get_fullsize_flag (gpointer o) {
-    return g_object_get_data (G_OBJECT(o), FULLSIZE) != 0;
+    return g_object_get_data (G_OBJECT(o), FULLSIZE) != nullptr;
   }
   bool toggle_fullsize_flag (gpointer o) {
     const bool b (!get_fullsize_flag (o));
@@ -192,8 +195,8 @@ namespace
     CURSOR_QTY
   };
 
-  GdkCursor ** cursors(0);
-  GdkCursor * cursor_current(0);
+  GdkCursor ** cursors(nullptr);
+  GdkCursor * cursor_current(nullptr);
 
   void free_cursors (void) {
     delete[] cursors;
@@ -209,23 +212,6 @@ namespace
 
       int width, height;
       const GtkIconSize size (GTK_ICON_SIZE_LARGE_TOOLBAR);
-#if !GTK_CHECK_VERSION(3,0,0)
-      GtkStyle * style (gtk_widget_get_style (w));
-      const GtkTextDirection dir (GTK_TEXT_DIR_NONE);
-      const GtkStateType state (GTK_STATE_PRELIGHT);
-
-      GtkIconSet * icon_set = gtk_style_lookup_icon_set (style, GTK_STOCK_ZOOM_IN);
-      GdkPixbuf * pixbuf = gtk_icon_set_render_icon (icon_set, style, dir, state, size, w, NULL);
-      g_object_get (G_OBJECT(pixbuf), "width", &width, "height", &height, NULL);
-      cursors[CURSOR_ZOOM_IN] = gdk_cursor_new_from_pixbuf (display, pixbuf, width/2, height/2);
-      g_object_unref (G_OBJECT(pixbuf));
-
-      icon_set = gtk_style_lookup_icon_set (style, GTK_STOCK_ZOOM_OUT);
-      pixbuf = gtk_icon_set_render_icon (icon_set, style, dir, state, size, w, NULL);
-      g_object_get (G_OBJECT(pixbuf), "width", &width, "height", &height, NULL);
-      cursors[CURSOR_ZOOM_OUT] = gdk_cursor_new_from_pixbuf (display, pixbuf, width/2, height/2);
-      g_object_unref (G_OBJECT(pixbuf));
-#else
       GdkPixbuf * pixbuf = gtk_widget_render_icon_pixbuf (w, GTK_STOCK_ZOOM_IN, size);
       g_object_get (G_OBJECT(pixbuf), "width", &width, "height", &height, NULL);
       cursors[CURSOR_ZOOM_IN] = gdk_cursor_new_from_pixbuf (display, pixbuf, width/2, height/2);
@@ -235,7 +221,6 @@ namespace
       g_object_get (G_OBJECT(pixbuf), "width", &width, "height", &height, NULL);
       cursors[CURSOR_ZOOM_OUT] = gdk_cursor_new_from_pixbuf (display, pixbuf, width/2, height/2);
       g_object_unref (G_OBJECT(pixbuf));
-#endif
 
       cursors[CURSOR_IBEAM] = gdk_cursor_new (GDK_XTERM);
       cursors[CURSOR_HREF] = gdk_cursor_new (GDK_HAND2);
@@ -342,7 +327,7 @@ namespace
     const int nw (size ? size->width : 0);
     const int nh (size ? size->height : 0);
 
-    GdkPixbuf * out (0);
+    GdkPixbuf * out (nullptr);
     if (nw>=100 && nh>=100)
     {
       const int ow (gdk_pixbuf_get_width (pixbuf));
@@ -374,12 +359,12 @@ namespace
 
     const int begin_offset (gtk_text_iter_get_offset (iter));
 
-    GdkPixbuf * original (0);
-    GdkPixbuf * old_scaled (0);
+    GdkPixbuf * original (nullptr);
+    GdkPixbuf * old_scaled (nullptr);
     if (!get_pixbuf_at_offset (buf, begin_offset, original, old_scaled))
       return;
 
-    GdkPixbuf * new_scaled (size_to_fit (original, (fullsize ? 0 : size)));
+    GdkPixbuf * new_scaled (size_to_fit (original, (fullsize ? nullptr : size)));
     const int old_w (gdk_pixbuf_get_width (old_scaled));
     const int new_w (gdk_pixbuf_get_width (new_scaled));
     const int old_h (gdk_pixbuf_get_height (old_scaled));
@@ -423,7 +408,7 @@ BodyPane :: mouse_button_pressed (GtkWidget *w, GdkEventButton *event)
       /* this is a crude way of making sure that double-click
        * doesn't open two or three browser windows. */
       static time_t last_url_time (0);
-      const time_t this_url_time (time (0));
+      const time_t this_url_time (time (nullptr));
       if (this_url_time != last_url_time) {
         last_url_time = this_url_time;
         URL :: open (_prefs, url.c_str());
@@ -597,11 +582,11 @@ namespace
                               int                      utf8_byte_len)
   {
     const char * str = utf8_line;
-    const char * line_end = utf8_line + utf8_byte_len;
     const char * retval = "quote_0";
 
     if (0<utf8_byte_len && str && *str)
     {
+      const char * line_end = utf8_line + utf8_byte_len;
       int depth = 0;
 
       // walk past leading spaces
@@ -619,12 +604,13 @@ namespace
         str = g_utf8_next_char (str);
       }
 
-      if (!depth)
-        retval = "quote_0";
-      else switch (depth % 3) {
-        case 1: retval = "quote_1"; break;
-        case 2: retval = "quote_2"; break;
-        case 0: retval = "quote_3"; break;
+      if (depth != 0)
+      {
+        switch (depth % 3) {
+          case 1: retval = "quote_1"; break;
+          case 2: retval = "quote_2"; break;
+          case 0: retval = "quote_3"; break;
+        }
       }
     }
 
@@ -649,12 +635,12 @@ namespace
 
  void create_emoticons()
   {
-    emoticon_pixbufs[":)"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_smile, false, 0);
-    emoticon_pixbufs[":-)"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_smile, false, 0);
-    emoticon_pixbufs[";)"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_wink, false, 0);
-    emoticon_pixbufs[":("] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_frown, false, 0);
-    emoticon_pixbufs[":P"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_tongueout, false, 0);
-    emoticon_pixbufs[":O"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_surprised, false, 0);
+    emoticon_pixbufs[":)"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_smile, false, nullptr);
+    emoticon_pixbufs[":-)"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_smile, false, nullptr);
+    emoticon_pixbufs[";)"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_wink, false, nullptr);
+    emoticon_pixbufs[":("] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_frown, false, nullptr);
+    emoticon_pixbufs[":P"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_tongueout, false, nullptr);
+    emoticon_pixbufs[":O"] = gdk_pixbuf_new_from_inline (-1, icon_mozilla_surprised, false, nullptr);
   }
 
   enum TagMode { ADD, REPLACE };
@@ -708,7 +694,7 @@ namespace
                                      GdkPixbuf          * pixbuf)
   {
     g_assert (!text.empty());
-    g_assert (pixbuf != 0);
+    g_assert (pixbuf != nullptr);
 
     GtkTextTagTable * tags (gtk_text_buffer_get_tag_table (buffer));
     GtkTextTag * url_tag (gtk_text_tag_table_lookup (tags, "url"));
@@ -750,7 +736,7 @@ namespace
                              bool                  do_urls)
   {
 
-    g_return_if_fail (buffer!=0);
+    g_return_if_fail (buffer!=nullptr);
     g_return_if_fail (GTK_IS_TEXT_BUFFER(buffer));
 
     // mute the quoted text, if desired
@@ -775,7 +761,7 @@ namespace
     gtk_text_buffer_apply_tag_by_name (buffer, "text", &mark_start, &end);
 
     // find where the signature begins...
-    const char * sig_point (0);
+    const char * sig_point (nullptr);
     int offset (0);
     if (GNKSA::find_signature_delimiter (v, offset) != GNKSA::SIG_NONE)
       sig_point = v.str + offset;
@@ -857,7 +843,7 @@ namespace
 
           if (e) {
             already_processed.insert (e);
-            const char * type (0);
+            const char * type (nullptr);
             switch (*b) {
               case '*': type = "bold"; break;
               case '_': type = "underline"; break;
@@ -877,7 +863,7 @@ namespace
       StringView march (v_all);
       while ((url_find (march, area))) {
         set_section_tag (buffer, &start, v_all, area, "url", REPLACE);
-        march = march.substr (area.str + area.len, 0);
+        march = march.substr (area.str + area.len, nullptr);
       }
     }
 
@@ -900,7 +886,7 @@ namespace
   GdkPixbuf* get_pixbuf_from_gmime_part (GMimePart * part)
   {
     GdkPixbufLoader * l (gdk_pixbuf_loader_new ());
-    GError * err (0);
+    GError * err (nullptr);
 
     // populate the loader
     GMimeDataWrapper * wrapper (g_mime_part_get_content (part));
@@ -941,7 +927,7 @@ namespace
     }
 
     // create the pixbuf
-    GdkPixbuf * pixbuf (0);
+    GdkPixbuf * pixbuf (nullptr);
     if (!err)
       pixbuf = gdk_pixbuf_loader_get_pixbuf (l);
     else {
@@ -983,9 +969,9 @@ BodyPane :: append_part (GMimeObject * parent, GMimeObject * obj, GtkAllocation
   {
     GdkPixbuf * original (get_pixbuf_from_gmime_part (part));
     const bool fullsize (!_prefs.get_flag ("size-pictures-to-fit", true));
-    GdkPixbuf * scaled (size_to_fit (original, fullsize ? 0 : widget_size));
+    GdkPixbuf * scaled (size_to_fit (original, fullsize ? nullptr : widget_size));
 
-    if (scaled != 0)
+    if (scaled != nullptr)
     {
       GtkTextIter iter;
 
@@ -1078,7 +1064,7 @@ namespace
   {
     const char * val (message ? g_mime_object_get_header ((GMimeObject *)message, key) : "");
     const std::string utf8_val (header_to_utf8 (val, fallback_charset));
-    char * e (0);
+    char * e (nullptr);
     if (strcmp (key, "From"))
       e = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>", utf8_val.c_str());
     else {
@@ -1123,7 +1109,7 @@ namespace
 void
 BodyPane :: set_text_from_message (GMimeMessage * message)
 {
-  const char * fallback_charset (_charset.empty() ? 0 : _charset.c_str());
+  const char * fallback_charset (_charset.empty() ? nullptr : _charset.c_str());
 
   // mandatory headers...
   std::string s;
@@ -1186,14 +1172,10 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
   s.resize (std::max((size_t)0,s.size()-1)); // remove trailing linefeed
   gtk_label_set_markup (GTK_LABEL(_headers), s.c_str());
 
-#if !GTK_CHECK_VERSION(3,0,0)
-  // ellipsize mode is useless w/o this in expander...
-  gtk_label_set_width_chars (GTK_LABEL(_headers), (int)w);
-#endif
 
   // set the x-face...
   gtk_image_clear(GTK_IMAGE(_xface));
-  const char * pch = message ? g_mime_object_get_header ((GMimeObject *) message, "X-Face") : 0;
+  const char * pch = message ? g_mime_object_get_header ((GMimeObject *) message, "X-Face") : nullptr;
   if (pch && gtk_widget_get_window(_xface) )
   {
     gtk_widget_set_size_request (_xface, FACE_SIZE, FACE_SIZE);
@@ -1207,7 +1189,7 @@ BodyPane :: set_text_from_message (GMimeMessage * message)
 
   // set the face
   gtk_image_clear(GTK_IMAGE(_face));
-  pch = message ? g_mime_object_get_header ((GMimeObject *) message, "Face") : 0;
+  pch = message ? g_mime_object_get_header ((GMimeObject *) message, "Face") : nullptr;
   if (pch && gtk_widget_get_window(_face))
   {
     gtk_widget_set_size_request (_face, FACE_SIZE, FACE_SIZE);
@@ -1361,7 +1343,7 @@ BodyPane :: clear ()
 {
   if (_message)
     g_object_unref (_message);
-  _message = 0;
+  _message = nullptr;
 
   set_cleared(true);
 
@@ -1520,6 +1502,7 @@ BodyPane :: copy_url_cb (GtkMenuItem *mi G_GNUC_UNUSED, gpointer pane)
 {
   static_cast<BodyPane*>(pane)->copy_url ();
 }
+
 void
 BodyPane :: copy_url ()
 {
@@ -1527,7 +1510,6 @@ BodyPane :: copy_url ()
                           _hover_url.c_str(), _hover_url.size());
 }
 
-
 void
 BodyPane :: populate_popup_cb (GtkTextView *v, GtkMenu *m, gpointer pane)
 {
@@ -1568,8 +1550,8 @@ namespace
     {
       gtk_menu_popup
       (GTK_MENU(bp->_menu), NULL, NULL, NULL, NULL,
-      (event ? event->button : 0),
-      (event ? event->time : 0));
+      event->button,
+      event->time);
     }
 
     return TRUE;
@@ -1611,7 +1593,7 @@ BodyPane :: menu_clicked_all_cb (GtkWidget* w, gpointer ptr)
 GtkWidget*
 BodyPane :: new_attachment (const char* filename)
 {
-  if (!filename) return 0;
+  if (!filename) return nullptr;
 
   GtkWidget* w = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   GtkWidget* attachment = gtk_label_new(filename);
@@ -1638,7 +1620,7 @@ BodyPane :: clear_attachments()
   _cur_col = 0;
   _cur_row = 0;
   _attachments = 0;
-  _current_attachment = 0;
+  _current_attachment = nullptr;
 
   {
     gtk_widget_set_no_show_all (_att_box, TRUE);
@@ -1661,21 +1643,6 @@ BodyPane :: add_attachment_to_toolbar (const char* fn)
 //  gtk_widget_set_size_request(w, -1, 32);
 
   ++_attachments;
-#if !GTK_CHECK_VERSION(3,0,0)
-
-  const guint cols(4);
-
-  if (_attachments % 4 == 0 && _attachments != 0)
-  {
-    ++_cur_row;
-    gtk_table_resize (GTK_TABLE(_att_toolbar), _cur_row, cols);
-    _cur_col = 0;
-  }
-
-  gtk_table_attach_defaults (GTK_TABLE(_att_toolbar), w, _cur_col, _cur_col+1, _cur_row,_cur_row+1);
-
-  ++_cur_col;
-#else
   if (_attachments % 4 == 0 && _attachments != 0)
   {
     gtk_grid_insert_row (GTK_GRID(_att_toolbar), ++_cur_row);
@@ -1683,7 +1650,6 @@ BodyPane :: add_attachment_to_toolbar (const char* fn)
   }
 
   gtk_grid_attach (GTK_GRID(_att_toolbar), w, _cur_col++, _cur_row, 1, 1);
-#endif  // 3.0.0
 
   gtk_widget_set_no_show_all (_att_box, FALSE);
   gtk_widget_show_all (_att_box);
@@ -1705,16 +1671,10 @@ BodyPane :: create_attachments_toolbar (GtkWidget* box)
   _cur_row = 0;
 
   GtkWidget * w;
-#if !GTK_CHECK_VERSION(3,0,0)
-  w = _att_toolbar = gtk_table_new(1,4,TRUE);
-  gtk_table_set_col_spacings (GTK_TABLE(w), PAD);
-  gtk_table_set_row_spacings (GTK_TABLE(w), PAD);
-#else
   w = _att_toolbar = gtk_grid_new();
   gtk_grid_insert_row (GTK_GRID(w), 0);
   gtk_grid_set_column_spacing (GTK_GRID(w), 3);
   gtk_grid_set_row_spacing (GTK_GRID (w), 4);
-#endif
   gtk_container_add (GTK_CONTAINER (box), w);
 
   return box;
@@ -1731,24 +1691,24 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   _header_pane(hp),
   _data (data),
   _cache (cache),
+#ifdef HAVE_WEBKIT
+  _web_view (webkit_web_view_new ()),
+#endif
   _hscroll_visible (false),
   _vscroll_visible (false),
-  _message (0),
+  _message (nullptr),
 #ifdef HAVE_GMIME_CRYPTO
 //  _gpgerr(GPG_DECODE),
 #endif
   _attachments(0),
-  _current_attachment(0),
-  _cleared (true)
-#ifdef HAVE_WEBKIT
-  ,_web_view (webkit_web_view_new ())
-#endif
+  _cleared (true),
+  _current_attachment(nullptr)
 {
 
   GtkWidget * w, * l, * hbox;
 
   for (guint i=0; i<NUM_ICONS; ++i)
-    icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, icons[i].pixbuf_txt, FALSE, 0);
+    icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, icons[i].pixbuf_txt, FALSE, nullptr);
 
   create_cursors();
   create_emoticons();
@@ -1779,11 +1739,7 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   gtk_widget_set_size_request (w, 50, -1);
   g_signal_connect (w, "activate", G_CALLBACK(expander_activated_cb), this);
   gtk_box_pack_start (GTK_BOX(vbox), w, false, false, 0);
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_box_pack_start (GTK_BOX(vbox), gtk_hseparator_new(), false, false, 0);
-#else
   gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
-#endif
 
   _terse = gtk_label_new ("Expander");
   g_object_ref_sink (G_OBJECT(_terse));
@@ -1836,24 +1792,16 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs, GroupPrefs
   GtkWidget * att_label = gtk_label_new (_("Attachments:"));
   gtk_misc_set_padding (GTK_MISC(att_label), PAD_SMALL, 0);
   gtk_misc_set_alignment (GTK_MISC(att_label), 0, 0);
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_box_pack_start (GTK_BOX(_att_box), gtk_hseparator_new(), false, false, 0);
-#else
   gtk_box_pack_start (GTK_BOX(_att_box), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
-#endif
   gtk_box_pack_start (GTK_BOX(_att_box), att_label, false, false, 0);
   gtk_box_pack_start (GTK_BOX(vbox), create_attachments_toolbar (_att_box), false, false, 0);
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_box_pack_start (GTK_BOX(vbox), gtk_hseparator_new(), false, false, 0);
-#else
   gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 0);
-#endif
 
   // set up the buffer tags
   _buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(_text));
   set_text_buffer_tags (_buffer, _prefs);
 
-  set_text_from_message (0);
+  set_text_from_message (nullptr);
   const bool expanded (_prefs.get_flag ("body-pane-headers-expanded", true));
   gtk_expander_set_expanded (GTK_EXPANDER(_expander), expanded);
   expander_activated_idle (this);
@@ -2035,7 +1983,7 @@ namespace
 GMimeMessage*
 BodyPane :: create_followup_or_reply (bool is_reply)
 {
-  GMimeMessage * msg (0);
+  GMimeMessage * msg (nullptr);
 
   if (_message)
   {
@@ -2046,7 +1994,7 @@ BodyPane :: create_followup_or_reply (bool is_reply)
     // fallback character encodings
     const char * group_charset (_charset.c_str());
     GMimeContentType * type (g_mime_object_get_content_type (GMIME_OBJECT(_message)));
-    const char * message_charset (type ? g_mime_content_type_get_parameter (type, "charset") : 0);
+    const char * message_charset (type ? g_mime_content_type_get_parameter (type, "charset") : nullptr);
 
     ///
     ///  HEADERS
@@ -2165,7 +2113,7 @@ BodyPane :: refresh_fonts ()
   const bool monospace_font_enabled = _prefs.get_flag ("monospace-font-enabled", false);
 
   if (!body_pane_font_enabled && !monospace_font_enabled)
-    gtk_widget_override_font (_text, 0);
+    gtk_widget_override_font (_text, nullptr);
   else {
     const std::string str (monospace_font_enabled
       ? _prefs.get_string ("monospace-font", "Monospace 10")
@@ -2202,12 +2150,12 @@ BodyPane :: on_prefs_string_changed (const StringView& key, const StringView& va
 
 void
 BodyPane :: on_prefs_color_changed (const StringView& key, const GdkColor& color G_GNUC_UNUSED)
-{		
-  if ((key == "text-color-fg")              || (key == "text-color-bg")              || 
-      (key == "body-pane-color-url")        || (key == "body-pane-color-url-bg")     || 
-      (key == "body-pane-color-quote-1")    || (key == "body-pane-color-quote-2")    || 
-      (key == "body-pane-color-quote-3")    || (key == "body-pane-color-quote-1-bg") || 
-      (key == "body-pane-color-quote-2-bg") || (key == "body-pane-color-quote-3-bg") || 
+{
+  if ((key == "text-color-fg")              || (key == "text-color-bg")              ||
+      (key == "body-pane-color-url")        || (key == "body-pane-color-url-bg")     ||
+      (key == "body-pane-color-quote-1")    || (key == "body-pane-color-quote-2")    ||
+      (key == "body-pane-color-quote-3")    || (key == "body-pane-color-quote-1-bg") ||
+      (key == "body-pane-color-quote-2-bg") || (key == "body-pane-color-quote-3-bg") ||
       (key == "body-pane-color-signature")  || (key == "body-pane-color-signature-bg"))
   {
     refresh_colors ();
@@ -2231,3 +2179,5 @@ BodyPane :: set_character_encoding (const char * charset)
 
   refresh ();
 }
+
+}
