@@ -13,19 +13,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef _GroupPane_h_
 #define _GroupPane_h_
 
-#include <gtk/gtk.h>
+#include "gtk-compat.h"
 #include <pan/general/quark.h>
 #include <pan/data/data.h>
 #include <pan/gui/action-manager.h>
 #include <pan/gui/pan-tree.h>
 #include <pan/gui/prefs.h>
+#include <pan/gui/group-prefs.h>
 
 namespace pan
 {
@@ -36,15 +37,15 @@ namespace pan
   class GroupPane: private Data::Listener, private Prefs::Listener
   {
     protected: // Data::Listener
-      virtual void on_grouplist_rebuilt ();
-      virtual void on_group_read (const Quark& group);
-      virtual void on_group_subscribe (const Quark& group, bool sub);
+      virtual void on_grouplist_rebuilt () override;
+      virtual void on_group_read (const Quark& group) override;
+      virtual void on_group_subscribe (const Quark& group, bool sub) override;
       virtual void on_group_counts (const Quark& group,
-                                    unsigned long unread,
-                                    unsigned long total);
+                                    Article_Count unread,
+                                    Article_Count total) override;
 
     public:
-      GroupPane (ActionManager&, Data&, Prefs&);
+      GroupPane (ActionManager&, Data&, Prefs&, GroupPrefs&);
       ~GroupPane ();
       GtkWidget* root () { return _root; }
       GtkWidget* get_default_focus_widget() { return _tree_view; }
@@ -57,17 +58,26 @@ namespace pan
 
     private:
       Prefs& _prefs;
+      GroupPrefs& _group_prefs;
       Data& _data;
       bool _collapsed;
       GtkWidget * _root;
       GtkWidget * _tree_view;
       PanTreeStore * _tree_store;
 
+    public:
+      GroupPrefs& get_group_prefs() { return _group_prefs; }
+      Prefs& get_prefs() { return _prefs; }
+
     private:
       GtkTreePath* find_next_subscribed_group (bool unread_only);
       void read_group (GtkTreePath*);
       void read_next_group_impl (bool unread_only);
 
+    public:
+      void read_group (const StringView&);
+      static bool is_virtual_group (const Quark& group);
+
     private:
       static void do_popup_menu (GtkWidget*, GdkEventButton*, gpointer);
       static gboolean on_button_pressed (GtkWidget*, GdkEventButton*, gpointer);
@@ -77,14 +87,14 @@ namespace pan
       void refresh_font ();
 
     public: // pretend these are private
-      void set_filter (const std::string& text);
+      void set_filter (const std::string& text, int mode);
       const ActionManager& _action_manager;
 
     private:
-      virtual void on_prefs_flag_changed (const StringView& key, bool value);
-      virtual void on_prefs_int_changed (const StringView& key, int color) { }
-      virtual void on_prefs_string_changed (const StringView& key, const StringView& value);
-      virtual void on_prefs_color_changed (const StringView& key, const GdkColor& color) { }
+      void on_prefs_flag_changed (const StringView& key, bool value) override;
+      void on_prefs_int_changed (const StringView&, int) override { }
+      void on_prefs_string_changed (const StringView& key, const StringView& value) override;
+      void on_prefs_color_changed (const StringView&, const GdkColor&) override;
 
     private:
       quarks_t _dirty_groups;
