@@ -13,28 +13,26 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #include <config.h>
 #include <cassert>
-extern "C" {
-  #include <glib/gi18n.h>
-}
+#include <climits>
+#include <glib/gi18n.h>
 #include <pan/general/debug.h>
 #include <pan/general/text-match.h>
 #include "hig.h"
 #include "pad.h"
 #include "score-add-ui.h"
 #include "score-view-ui.h"
+#include "gtk-compat.h"
+
+#include <pan/general/null.h>
 
 using namespace pan;
 
-#if !GTK_CHECK_VERSION(2,6,0)
-#define GTK_STOCK_EDIT GTK_STOCK_OPEN
-#endif
-
 /**
 *** Key - Value paired comboboxes
 **/
@@ -42,7 +40,7 @@ namespace
 {
   enum { VALUE_STR, VALUE_TYPE, VALUE_COLS };
 
-  GtkWidget * value_combo_new (GtkTreeModel * model=0)
+  GtkWidget * value_combo_new (GtkTreeModel * model=nullptr)
   {
     GtkWidget *  w = model
       ? gtk_combo_box_new_with_model (model)
@@ -106,16 +104,16 @@ namespace
   ***
   **/
 
-  enum { ADD, SUBTRACT, ASSIGN, WATCH, IGNORE };
+  enum { _ADD, _SUBTRACT, _ASSIGN, _WATCH, _IGNORE };
 
   GtkTreeModel * score_tree_model_new ()
   {
     struct { int type; const char * str; } items[] = {
-      { ADD,      N_("increase the article's score by") },
-      { SUBTRACT, N_("decrease the article's score by") },
-      { ASSIGN,   N_("set the article's score to") },
-      { WATCH,    N_("watch the article (set its score to 9999)") },
-      { IGNORE,   N_("ignore the article (set its score to -9999)") }
+      { _ADD,      N_("increase the article's score by") },
+      { _SUBTRACT, N_("decrease the article's score by") },
+      { _ASSIGN,   N_("set the article's score to") },
+      { _WATCH,    N_("watch the article (set its score to 9999)") },
+      { _IGNORE,   N_("ignore the article (set its score to -9999)") }
     };
 
     GtkListStore * store = gtk_list_store_new (VALUE_COLS, G_TYPE_STRING, G_TYPE_INT);
@@ -161,13 +159,13 @@ namespace
   /**
   **/
 
-  enum Days { WEEK=7, MONTH=30, FOREVER=0 };
+  enum Days { MONTH=31, MONTHS=(31*6), FOREVER=0 };
 
   GtkTreeModel* time_tree_model_new ()
   {
     struct { int type; const char * str; } items[] = {
-      { WEEK,       N_("the next week") },
-      { MONTH,      N_("the next month") },
+      { MONTH,      N_("for the next month") },
+      { MONTHS,     N_("for the next six months") },
       { FOREVER,    N_("forever") },
     };
 
@@ -197,9 +195,9 @@ namespace
       { TextMatch::CONTAINS,    true,  N_("doesn't contain")},
       { TextMatch::IS,          false, N_("is")},
       { TextMatch::IS,          true,  N_("isn't")},
-      { TextMatch::BEGINS_WITH, false, N_("starts with")}, 
+      { TextMatch::BEGINS_WITH, false, N_("starts with")},
       { TextMatch::ENDS_WITH,   false, N_("ends with")},
-      { TextMatch::REGEX,       false, N_("matches regex")}, 
+      { TextMatch::REGEX,       false, N_("matches regex")},
     };
 
     GtkListStore * store = gtk_list_store_new (TEXT_MATCH_COLS, G_TYPE_STRING, G_TYPE_INT, G_TYPE_BOOLEAN);
@@ -316,12 +314,12 @@ namespace
                                 GtkWidget     *& setme_spin,
                                 const Article  * article)
   {
-    GtkWidget * h = gtk_hbox_new (false, PAD);
+    GtkWidget * h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     g_object_set_data (G_OBJECT(h), "article", gpointer(article));
 
     GtkTreeModel * model = field_tree_model_new ();
     GtkWidget * field = setme_field = value_combo_new (model);
-    g_object_unref (G_OBJECT(model)); 
+    g_object_unref (G_OBJECT(model));
     gtk_box_pack_start (GTK_BOX(h), field, false, false, 0);
     g_signal_connect (field, "changed", G_CALLBACK(field_changed_cb), h);
     g_object_set_data (G_OBJECT(h), "field", field);
@@ -335,8 +333,8 @@ namespace
     gtk_box_pack_start (GTK_BOX(h), entry, true, true, 0);
     g_object_set_data (G_OBJECT(h), "entry", entry);
 
-    GtkObject * a = gtk_adjustment_new (100, -ULONG_MAX, ULONG_MAX, 1.0, 1.0, 1.0);
-    GtkWidget * spin = setme_spin = gtk_spin_button_new (GTK_ADJUSTMENT(a), 100.0, 0u);
+    GtkAdjustment * a = (GtkAdjustment*)gtk_adjustment_new (100, -ULONG_MAX, ULONG_MAX, 1.0, 1.0, 0.0);
+    GtkWidget * spin = setme_spin = gtk_spin_button_new (a, 100.0, 0u);
     gtk_box_pack_start (GTK_BOX(h), spin, false, false, 0);
     g_object_set_data (G_OBJECT(h), "spin", spin);
 
@@ -355,7 +353,7 @@ namespace
 void
 ScoreAddDialog :: add_this_to_scorefile (bool do_rescore)
 {
-  
+
   // section
   bool negate (false);
   int value (0);
@@ -408,11 +406,10 @@ ScoreAddDialog :: add_this_to_scorefile (bool do_rescore)
     {
       // Xref is of form server group1:number1 group2:number2
       // so to count the crossposts, test for some number of colons.
-      // for >= 1 groups, use *:* 
-      // for >= 2 groups, use *:*:*  (negate to test for < 2 groups...)
-      const int more_than = (int) gtk_spin_button_get_value (GTK_SPIN_BUTTON (_numeric_criteria_spin));
-      item.value = ".*";
-      for (int i=0; i<=more_than; ++i) item.value += ":.*";
+      const int gt = (int) gtk_spin_button_get_value (GTK_SPIN_BUTTON (_numeric_criteria_spin));
+      char buf[512];
+      snprintf (buf, sizeof(buf), "(.*:){%d} %% crossposted to %d or more groups ", gt+1, gt+1);
+      item.value = buf;
       item.negate = rel != VAL_GT;
     }
     else // lines, bytes
@@ -433,11 +430,11 @@ ScoreAddDialog :: add_this_to_scorefile (bool do_rescore)
   const int spin_score (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(_score_spin)));
   value = value_combo_get (GTK_COMBO_BOX(_score_menu));
   switch (value) {
-    case ADD:       assign_flag=false; score =  spin_score; break;
-    case SUBTRACT:  assign_flag=false; score = -spin_score; break;
-    case ASSIGN:    assign_flag=true;  score =  spin_score; break;
-    case WATCH:     assign_flag=true;  score =  9999;       break;
-    case IGNORE:    assign_flag=true;  score = -9999;       break;
+    case _ADD:       assign_flag=false; score =  spin_score; break;
+    case _SUBTRACT:  assign_flag=false; score = -spin_score; break;
+    case _ASSIGN:    assign_flag=true;  score =  spin_score; break;
+    case _WATCH:     assign_flag=true;  score =  9999;       break;
+    case _IGNORE:    assign_flag=true;  score = -9999;       break;
   }
 
   // duration in days
@@ -536,10 +533,10 @@ ScoreAddDialog :: populate (const Quark& group, const Article& a, Mode mode)
   // score
   int score_mode;
   switch (mode) {
-    case WATCH_SUBTHREAD: score_mode = WATCH; break;
+    case WATCH_SUBTHREAD: score_mode = _WATCH; break;
     case PLONK:
-    case IGNORE_SUBTHREAD: score_mode = IGNORE; break;
-    default: score_mode = ADD; break;
+    case IGNORE_SUBTHREAD: score_mode = _IGNORE; break;
+    default: score_mode = _ADD; break;
   }
   gtk_spin_button_set_value (GTK_SPIN_BUTTON(_score_spin), 100);
   value_combo_set (GTK_COMBO_BOX(_score_menu), score_mode);
@@ -548,26 +545,6 @@ ScoreAddDialog :: populate (const Quark& group, const Article& a, Mode mode)
   value_combo_set (GTK_COMBO_BOX(_duration_menu), MONTH);
 }
 
-namespace
-{
-  const char * SENSITIVE_LIST ("sensitive_list");
-
-  void
-  refresh_enabled_states (GtkToggleButton * tb)
-  {
-    GSList * s = (GSList*) g_object_get_data (G_OBJECT(tb), SENSITIVE_LIST);
-    const bool active (gtk_toggle_button_get_active (tb));
-    for (GSList * l=s; l!=0; l=l->next)
-      gtk_widget_set_sensitive (GTK_WIDGET(l->data), active);
-  }
-
-  void
-  toggled_cb (GtkToggleButton * tb, gpointer user_data)
-  {
-    refresh_enabled_states (tb);
-  }
-}
-
 namespace
 {
   GtkWidget* create_rescore_button ()
@@ -575,12 +552,12 @@ namespace
     GtkWidget * button = gtk_button_new ();
     GtkWidget * label = gtk_label_new_with_mnemonic (_("Add and Re_score"));
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-			      
+
     GtkWidget * image = gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
     GtkWidget * image2 = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
-    GtkWidget * hbox = gtk_hbox_new (FALSE, 2);
+    GtkWidget * hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     GtkWidget * align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-					        
+
     gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (hbox), image2, FALSE, FALSE, 0);
     gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -605,7 +582,7 @@ namespace
     const int value = value_combo_get (w);
 
     GtkWidget * spin (GTK_WIDGET (spin_gpointer));
-    if (value==WATCH || value==IGNORE)
+    if (value==_WATCH || value==_IGNORE)
       gtk_widget_hide (spin);
     else
       gtk_widget_show (spin);
@@ -620,9 +597,12 @@ ScoreAddDialog :: ScoreAddDialog (Data           & data,
   _data (data),
   _article (article),
   _group (group),
-  _root (0)
+  _root (nullptr)
 {
-  GtkWidget * w = _root = gtk_dialog_new_with_buttons (_("Pan: New Scoring Rule"),
+  std::string s (_("Pan"));
+  s += ": ";
+  s += _("New Scoring Rule");
+  GtkWidget * w = _root = gtk_dialog_new_with_buttons (s.c_str(),
     GTK_WINDOW(gtk_widget_get_toplevel(parent)),
     GTK_DIALOG_DESTROY_WITH_PARENT,
     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -640,38 +620,38 @@ ScoreAddDialog :: ScoreAddDialog (Data           & data,
 
   int row = 0;
   GtkWidget * t = HIG :: workarea_create ();
-  gtk_box_pack_start (GTK_BOX(GTK_DIALOG(_root)->vbox), t, true, true, 0);
+  gtk_box_pack_start (GTK_BOX( gtk_dialog_get_content_area( GTK_DIALOG(_root))), t, true, true, 0);
   HIG::workarea_add_section_title (t, &row, _("New Scoring Rule"));
     HIG::workarea_add_section_spacer (t, row, 4);
 
     // section
-    GtkWidget * h = gtk_hbox_new (false, PAD);
+    GtkWidget * h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD);
     GtkTreeModel * model = text_tree_model_new (false);
     w = _section_menu = value_combo_new (model);
     g_object_unref (G_OBJECT(model));
     gtk_box_pack_start (GTK_BOX(h), w, false, false, 0);
     w = _section_entry = gtk_entry_new ();
     gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
-    HIG::workarea_add_row (t, &row, _("If the group name"), h);
+    HIG::workarea_add_row (t, &row, _("Group name"), h);
     gtk_widget_show_all (h);
 
     // criteria
     w = criteria_line_new (_field_menu, _criteria_menu,
                            _text_criteria_entry, _numeric_criteria_spin,
                            &_article);
-    HIG::workarea_add_row (t, &row, _("And the article's"), w);
+    HIG::workarea_add_row (t, &row, _("and"), w);
     gtk_widget_show (w);
 
     // score
-    h = gtk_hbox_new (false, PAD_SMALL); 
+    h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, PAD_SMALL);
     model = score_tree_model_new ();
     w = _score_menu = value_combo_new (model);
     g_object_unref (model);
     gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
-    GtkObject * a = gtk_adjustment_new (100, INT_MIN, INT_MAX, 1.0, 1.0, 1.0);
-    w = _score_spin = gtk_spin_button_new (GTK_ADJUSTMENT(a), 100.0, 0u);
+    GtkAdjustment * a = (GtkAdjustment*)gtk_adjustment_new (100, INT_MIN, INT_MAX, 1.0, 1.0, 0.0);
+    w = _score_spin = gtk_spin_button_new (a, 100.0, 0u);
     gtk_box_pack_start (GTK_BOX(h), w, true, true, 0);
-    HIG::workarea_add_row (t, &row, _("Then"), h);
+    HIG::workarea_add_wide_control (t, &row, h);
     gtk_widget_show_all (h);
     g_signal_connect (_score_menu, "changed", G_CALLBACK(score_combo_changed_cb), w);
 
@@ -679,7 +659,7 @@ ScoreAddDialog :: ScoreAddDialog (Data           & data,
     model = time_tree_model_new ();
     w = _duration_menu = value_combo_new (model);
     g_object_unref (model);
-    HIG::workarea_add_row (t, &row, _("For"), w);
+    HIG::workarea_add_wide_control (t, &row, w);
     gtk_widget_show (w);
 
   populate (group, article, mode);
