@@ -17,6 +17,8 @@
  *
  */
 
+#include "server-ui.h"
+
 #include <config.h>
 #include <cstdlib>
 #include <cstring>
@@ -31,7 +33,6 @@
 #include <pan/general/quark.h>
 #include <pan/data/data.h>
 #include <pan/usenet-utils/ssl-utils.h>
-#include "server-ui.h"
 #include "pad.h"
 #include "hig.h"
 #include "gtk-compat.h"
@@ -42,15 +43,15 @@
 #endif
 
 #ifdef HAVE_GKR
-#if GTK_CHECK_VERSION(3,0,0)
   #define GCR_API_SUBJECT_TO_CHANGE
   #include <libsecret/secret.h>
   #include <gcr/gcr.h>
   #undef GCR_API_SUBJECT_TO_CHANGE
-#endif /* GTK_CHECK_VERSION(3,0,0) */
 #endif
 
-using namespace pan;
+#include <pan/general/null.h>
+
+namespace pan {
 
 /************
 *************  EDIT DIALOG
@@ -77,9 +78,26 @@ namespace
     GtkWidget * compression_combo;
     GtkWidget * ssl_combo;
     GtkWidget * always_trust_checkbox;
-    ServerEditDialog (Data& d, Queue& q, Prefs& p): data(d), queue(q), prefs(p) {}
     CompressionType compressiontype;
 
+    ServerEditDialog (Data& d, Queue& q, Prefs& p):
+      data(d),
+      queue(q),
+      prefs(p),
+      dialog(nullptr),
+      address_entry(nullptr),
+      port_spin(nullptr),
+      auth_username_entry(nullptr),
+      auth_password_entry(nullptr),
+      connection_limit_spin(nullptr),
+      expiration_age_combo(nullptr),
+      rank_combo(nullptr),
+      compression_combo(nullptr),
+      ssl_combo(nullptr),
+      always_trust_checkbox(nullptr),
+      compressiontype(HEADER_COMPRESS_NONE)
+    {}
+
   };
 
   void pan_entry_set_text (GtkWidget * w, const StringView& v)
@@ -129,7 +147,7 @@ namespace
   edit_dialog_populate (Data&, Prefs& prefs, const Quark& server, ServerEditDialog * d)
   {
     // sanity clause
-    g_return_if_fail (d!=0);
+    g_return_if_fail (d!=nullptr );
     g_return_if_fail (GTK_IS_WIDGET(d->dialog));
 
     d->server = server;
@@ -231,11 +249,7 @@ namespace
       const int max_conn (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(d->connection_limit_spin)));
       StringView user (pan_entry_get_text (d->auth_username_entry));
 #ifdef HAVE_GKR
-#if GTK_CHECK_VERSION(3,0,0)
       gchar* pass = gcr_secure_memory_strdup(gtk_entry_get_text(GTK_ENTRY(d->auth_password_entry)));
-#else
-      gchar* pass = gnome_keyring_memory_strdup(gtk_entry_get_text(GTK_ENTRY(d->auth_password_entry)));
-#endif /* GTK_CHECK_VERSION(3,0,0) */
 #else
       gchar* pass = (gchar*)gtk_entry_get_text(GTK_ENTRY(d->auth_password_entry));
 #endif
@@ -265,7 +279,7 @@ namespace
       if (gtk_combo_box_get_active_iter (combo, &iter))
         gtk_tree_model_get (gtk_combo_box_get_model(combo), &iter, 1, &header_comp, -1);
 
-      const char * err_msg (0);
+      const char * err_msg (nullptr);
       if (addr.empty())
         err_msg = _("Please specify the server's address.");
 
@@ -308,7 +322,7 @@ namespace
 }
 
 std::string
-pan :: import_sec_from_disk_dialog_new (Data& data, Queue& queue, GtkWindow * window)
+import_sec_from_disk_dialog_new (Data& data, Queue& queue, GtkWindow * window)
 {
   std::string prev_path = g_get_home_dir ();
   std::string res;
@@ -345,7 +359,7 @@ namespace
 }
 
 GtkWidget*
-pan :: server_edit_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow * window, const Quark& server)
+server_edit_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow * window, const Quark& server)
 {
   ServerEditDialog * d (new ServerEditDialog (data, queue, prefs));
 
@@ -533,8 +547,8 @@ namespace
     const guint8 * pixbuf_txt;
     GdkPixbuf * pixbuf;
   } _icons[ICON_QTY] = {
-    { icon_plain,  0 },
-    { icon_cert,   0 }
+    { icon_plain,  nullptr },
+    { icon_cert,   nullptr }
   };
 }
 
@@ -563,14 +577,23 @@ namespace
     GtkListStore * servers_store;
     GtkWidget * remove_button;
     GtkWidget * edit_button;
-    ServerListDialog (Data& d, Queue& q, Prefs& p): data(d), queue(q), prefs(p) {}
+    ServerListDialog (Data& d, Queue& q, Prefs& p):
+      data(d),
+      queue(q),
+      prefs(p),
+      server_tree_view(nullptr),
+      dialog(nullptr),
+      servers_store(nullptr),
+      remove_button(nullptr),
+      edit_button(nullptr)
+    {}
   };
 
 
   Quark
   get_selected_server (ServerListDialog * d)
   {
-    g_assert (d != 0);
+    g_assert (d != nullptr);
 
     Quark server;
 
@@ -578,7 +601,7 @@ namespace
     GtkTreeModel * model;
     GtkTreeIter iter;
     if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-      char * host (0);
+      char * host (nullptr);
       gtk_tree_model_get (model, &iter, COL_DATA, &host, -1);
       if (host) {
         server = host;
@@ -593,7 +616,7 @@ namespace
   Quark
   get_selected_server_name (ServerListDialog * d)
   {
-    g_assert (d != 0);
+    g_assert (d != nullptr);
 
     Quark server;
 
@@ -601,7 +624,7 @@ namespace
     GtkTreeModel * model;
     GtkTreeIter iter;
     if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-      char * host (0);
+      char * host (nullptr);
       gtk_tree_model_get (model, &iter, COL_HOST, &host, -1);
       if (host) {
         server = host;
@@ -776,7 +799,7 @@ namespace
         if (!buf) g_snprintf(buf,sizeof(buf), "%s", _("No information available.")) ;
 
         GtkWidget * w = gtk_message_dialog_new (
-        0,
+        nullptr,
         GtkDialogFlags(GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT),
         GTK_MESSAGE_INFO,
         GTK_BUTTONS_CLOSE, NULL);
@@ -904,7 +927,7 @@ namespace
 #endif
 
 GtkWidget*
-pan :: server_list_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent)
+server_list_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent)
 {
   ServerListDialog * d = new ServerListDialog (data, queue, prefs);
 
@@ -980,7 +1003,7 @@ pan :: server_list_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow
 
 
 void
-pan :: render_cert_flag (GtkTreeViewColumn * ,
+render_cert_flag (GtkTreeViewColumn * ,
                          GtkCellRenderer   * renderer,
                          GtkTreeModel      * model,
                          GtkTreeIter       * iter,
@@ -993,13 +1016,13 @@ pan :: render_cert_flag (GtkTreeViewColumn * ,
 
 
 GtkWidget*
-pan :: sec_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent)
+sec_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent)
 {
 #ifdef HAVE_GNUTLS
   ServerListDialog * d = new ServerListDialog (data, queue, prefs);
 
   for (guint i=0; i<ICON_QTY; ++i)
-    _icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, _icons[i].pixbuf_txt, FALSE, 0);
+    _icons[i].pixbuf = gdk_pixbuf_new_from_inline (-1, _icons[i].pixbuf_txt, FALSE, nullptr);
 
   // dialog
   char * title = g_strdup_printf ("Pan: %s", _("SSL Certificates"));
@@ -1024,7 +1047,7 @@ pan :: sec_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent
 
   GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_PIXBUF, "xpad", 2,"ypad", 0,NULL));
   GtkTreeViewColumn * column = gtk_tree_view_column_new_with_attributes (_("Certificates"), r, NULL);
-  gtk_tree_view_column_set_cell_data_func (column, r, render_cert_flag, 0, 0);
+  gtk_tree_view_column_set_cell_data_func (column, r, render_cert_flag, nullptr, nullptr);
   gtk_tree_view_append_column (GTK_TREE_VIEW(w), column);
 
   r = gtk_cell_renderer_text_new ();
@@ -1078,3 +1101,5 @@ pan :: sec_dialog_new (Data& data, Queue& queue, Prefs& prefs, GtkWindow* parent
   return 0;
 #endif
 }
+
+}
